# web 常用服务

# 历史版本

```
0.0.1：权限管理\_api 多个项目使用
0.0.2：第一个试用版
0.0.3: 增加 api 权限过滤
0.0.3.1: 刷新 token.
0.0.3.2: 增加表 sys_dict 、 sys_dict_type 和 sys_config
0.0.3.x cacheManage
0.0.4 2024-07-26
0.0.5
    字符格式化 right.po
0.0.6
    cache
0.0.7
0.0.8
    pillow-10.4.0
    资源
0.0.9
    delete->aop.getuserId
0.0.10 发布
    token invalid
0.0.11 发布
    resource 增加 URL 处理
0.0.12 发布
    在view_model 引用api模块中的内容可能出现循环引用问题，移动了相关代码
    BUG 增加用户是未对密码加密BUG
0.0.13
    修改不完全. 弃用改版本
    依赖模块变更做了调整
0.0.14
    依赖模块变更做了调整
0.0.15
    字典增加 flag 字典,
    menu_view batch_add
0.0.16
    文件管理
0.0.17
    优化
0.0.18
    文件管理 批量删除APi
0.0.19
    DictSelectView 增加一个参数
    修复已知bug
0.0.20
    增加文件管理 重命名APi
0.0.21
    增加获取文件内容API
    优化部分逻辑
```
